@@ -42,8 +42,6 @@ Q_SIGNALS:
     void settingChanged(int column, int row);
 
 private:
-    int column;
-    int row;
     QLineEdit *columnEdit;
     QLineEdit *rowEdit;
     QPushButton *okButton;
